﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Syncfusion.Windows.Forms.Diagram;

namespace UpdateModelSize
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent(); 
            diagram1.Controller = new CustomController(diagram1);
            //Assign the Diagram's Controller to View's controller after initializing the customcontroller
            diagram1.View.Controller = diagram1.Controller;
            diagram1.Model.BoundaryConstraintsEnabled = false;
            //update the model size based on the content
            diagram1.Model.SizeToContent = true;            
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            PopulateFields(SetDataSource());
            HierarchicLayoutManager hierarchicalLayout = new HierarchicLayoutManager(this.diagram1.Model, 0, 70, 40);
            hierarchicalLayout.LeftMargin = 50;
            hierarchicalLayout.TopMargin = 50;

            hierarchicalLayout.Model.RightMargin = 50;
            hierarchicalLayout.Model.BottomMargin = 50;
            this.diagram1.LayoutManager = hierarchicalLayout;
            this.diagram1.LayoutManager.UpdateLayout(null);
            diagram1.View.SelectionList.Clear();
        }

        private void PopulateFields(DataTable dt)
        {
            for (int i = 0; i < dt.Rows.Count; i++)
            {
                Syncfusion.Windows.Forms.Diagram.RoundRect rect = new Syncfusion.Windows.Forms.Diagram.RoundRect(0, 0, 120, 60, MeasureUnits.Pixel);
                rect.FillStyle.Color = Color.FromArgb(255, 86, 4);
                rect.FillStyle.ForeColor = Color.FromArgb(255, 165, 74);
                rect.LineStyle.LineColor = Color.White;
                rect.FillStyle.Type = FillStyleType.LinearGradient;
                //rect.EnableShading = true;
                rect.Name = dt.Rows[i]["Name"].ToString();
                Syncfusion.Windows.Forms.Diagram.Label label = new Syncfusion.Windows.Forms.Diagram.Label(rect, dt.Rows[i]["Name"].ToString());
                label.FontStyle.Family = "Segoe UI";
                label.FontStyle.Size = 9;
                label.FontColorStyle.Color = Color.White;
                rect.Labels.Add(label);
                Syncfusion.Windows.Forms.Diagram.Label label1 = new Syncfusion.Windows.Forms.Diagram.Label(rect, dt.Rows[i]["Designation"].ToString());
                label1.FontStyle.Family = "Segoe UI";
                label1.FontStyle.Size = 9;
                label1.FontColorStyle.Color = Color.White;
                label1.OffsetX = rect.BoundingRectangle.Width / 2 - label1.Size.Width / 2;
                label1.OffsetY = rect.BoundingRectangle.Height / 2 + 5;
                rect.Labels.Add(label1);
                diagram1.Model.AppendChild(rect);
                if (!string.IsNullOrEmpty(dt.Rows[i]["ParentName"].ToString()))
                {
                    Syncfusion.Windows.Forms.Diagram.RoundRect parentNode = diagram1.Model.Nodes.FindNodeByName(dt.Rows[i]["ParentName"].ToString()) as Syncfusion.Windows.Forms.Diagram.RoundRect;
                    string ss = parentNode.Name;
                    ConnectNodes(parentNode, rect);
                }
            }
        }
        private void ConnectNodes(Node parentNode, Node childNode)
        {
            if (parentNode != null && childNode != null)
            {
                OrgLineConnector conn = new OrgLineConnector(PointF.Empty, new PointF(0, 1));
                conn.VerticalDistance = 35;
                conn.LineStyle.LineColor = Color.Gray;
                Decorator decor = conn.HeadDecorator;
                decor.DecoratorShape = DecoratorShape.Filled45Arrow;
                decor.FillStyle.Color = Color.White;
                decor.LineStyle.LineColor = Color.Gray;

                this.diagram1.Model.AppendChild(conn);

                parentNode.CentralPort.TryConnect(conn.TailEndPoint);
                childNode.CentralPort.TryConnect(conn.HeadEndPoint);

                this.diagram1.Model.SendToBack(conn);

            }
        }
        private DataTable SetDataSource()
        {
            DataTable table = new DataTable();
            table.Columns.Add("ID", typeof(string));
            table.Columns.Add("Name", typeof(string));
            table.Columns.Add("Designation", typeof(string));
            table.Columns.Add("ParentName", typeof(string));
            //
            // Here we add five DataRows.
            //
            table.Rows.Add("1", "John Smith", "CEO", string.Empty);
            table.Rows.Add("2", "Joe Robert", "Manager-SLS", "John Smith");
            table.Rows.Add("3", "Jack Kent", "Manager-Mkt", "John Smith");
            table.Rows.Add("4", "Ravi kumar", "Manager-DEV", "John Smith");
            table.Rows.Add("5", "Sue Raymond", "CSR", "Joe Robert");
            table.Rows.Add("6", "Lisa Simpson", "CSR", "Joe Robert");
            table.Rows.Add("7", "Bob Woley", "PM", "Jack Kent");
            table.Rows.Add("8", "Ron Jones", "Engineer", "Ravi kumar");
            table.Rows.Add("9", "Dave Mason", "Engineer", "Ravi kumar");

            return table;
        }


    }
}
